@@ -1,7 +1,13 @@
 import subprocess
-from spotii.define import *
 import threading
 from gpiozero import Button
+
+import sys, os, inspect
+currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
+parentdir = os.path.dirname(currentdir)
+sys.path.insert(0, parentdir)
+
+from define import *
 #from .takePhoto import takePhoto
 powerButton = Button(POWER_BUTTON_PIN,True,None,None,POWER_BUTTON_HOLD_TIME)
 def shutDown():
